@@ -8,8 +8,8 @@
 #include <utility>
 #include <vector>
 
-#include <pybind11/pybind11.h>
 #include <functional>
+#include <pybind11/pybind11.h>
 #include <string>
 #include <HepMC3/Version.h>
 #include <HepMC3/Reader.h>
@@ -20,19 +20,19 @@
 #include <HepMC3/WriterRootTree.h>
 #include <HepMC3/ReaderRoot.h>
 #include <HepMC3/ReaderRootTree.h>
-#include <src/root_binders.h>
+#include <src/rootIObinders.h>
 
 
 #ifndef BINDER_PYBIND11_TYPE_CASTER
 	#define BINDER_PYBIND11_TYPE_CASTER
-	PYBIND11_DECLARE_HOLDER_TYPE(T, std::shared_ptr<T>)
-	PYBIND11_DECLARE_HOLDER_TYPE(T, T*)
+	PYBIND11_DECLARE_HOLDER_TYPE(T, std::shared_ptr<T>, false)
+	PYBIND11_DECLARE_HOLDER_TYPE(T, T*, false)
 	PYBIND11_MAKE_OPAQUE(std::shared_ptr<void>)
 #endif
 
 void bind_pyHepMC3rootIO_2(std::function< pybind11::module &(std::string const &namespace_) > &M)
 {
-	// HepMC3::ReaderRoot file:HepMC3/ReaderRoot.h line:32
-	 binder::ReaderRoot_binder(M("HepMC3"));
+	// HepMC3::ReaderRoot file:HepMC3/ReaderRoot.h line:
+	binder::ReaderRoot_binder(M("HepMC3"));
 
 }
